Description Usage Arguments Value Examples
This function allows you to input 10X single-cell RNAseq profile (loading sparse data matrices provided by 10X genomics), and remove some unwanted cells.
1 2 3 4 5 6 7 8 | FilterData(
PathToData = ".",
FeatureColumn = 2,
UniqueFeatures = TRUE,
FeatureSuffixTrim = FALSE,
MinFeatures = 200,
MinUMIs = 500
)
|
PathToData |
Folder with barcodes.tsv, features.tsv (or genes.tsv), matrix.mtx. Default is the current folder |
FeatureColumn |
choose the column of genes.tsv or features.tsv for feature identifiers; default is 2 |
UniqueFeatures |
Logical for unique feature identifiers (default TRUE) |
FeatureSuffixTrim |
Logicalfor removal of trailing "-1" in cell barcodes (default FALSE) |
MinFeatures |
Threshold to remove those cell barcodes with found features fewer than it (default 200) |
MinUMIs |
threshold to remove those cell barcodes with found UMIs fewer than it (default 500) |
a sparse matrix containing the expression data will be returned.
1 2 3 4 | # For output from CellRanger < 3.0
FilterData("outs/filtered_gene_bc_matrices_mex/GRCh38/")
# For output from CellRanger >= 3.0
FilterData("outs/filtered_feature_bc_matrix/")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.